pub fn is_point_in_triangle(
p: Vector,
v1: Vector,
v2: Vector,
v3: Vector,
) -> Option<bool>Expand description
Returns true if point p is in triangle with corners v1, v2 and v3.
Returns None if the triangle is invalid i.e. all points are the same or on a straight line.